var _circle, _Button, _Button2, _Button3, _Button4, _Button5, _Button6, _Button7, _Button8, _Button10, _Button11, _Button12, _Button13, _Button14, _Button15, _Button16, _Button17;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, screen, waitFor } from '@testing-library/react';
import { vi } from 'vitest';
import userEvent from '@testing-library/user-event';
import '@testing-library/jest-dom';
import { runAxeCheck } from '@instructure/ui-axe-check';
import { Button } from '../index';
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
describe('<Button/>', () => {
  var _Button9;
  let consoleWarningMock;
  let consoleErrorMock;
  const iconSelector = 'svg[data-title="myIcon"]';
  const icon = _jsx("svg", {
    "data-title": "myIcon",
    height: "1em",
    width: "1em",
    style: {
      fill: 'currentcolor'
    },
    children: _circle || (_circle = _jsx("circle", {
      cx: "0.5em",
      cy: "0.5em",
      r: "0.5em"
    }))
  });
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleWarningMock = vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render children', () => {
    const children = 'Hello world';
    render(_jsx(Button, {
      children: children
    }));
    const button = document.querySelector('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent(children);
  });
  it('should render a button', async () => {
    render(_Button || (_Button = _jsx(Button, {
      children: "Hello World"
    })));
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'button');
    expect(button).toHaveTextContent('Hello World');
  });
  it('should provide a focused getter', () => {
    var _componentRef;
    let componentRef;
    render(_jsx(Button
    //@ts-expect-error TODO this is coming from ReactComponentWrapper
    , {
      ref: component => {
        componentRef = component;
      },
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    button.focus();
    expect((_componentRef = componentRef) === null || _componentRef === void 0 ? void 0 : _componentRef.focused).toBe(true);
  });
  it('should provide a focus function', () => {
    var _componentRef2;
    let componentRef;
    render(_jsx(Button
    //@ts-expect-error TODO this is coming from ReactComponentWrapper
    , {
      ref: component => {
        componentRef = component;
      },
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    (_componentRef2 = componentRef) === null || _componentRef2 === void 0 ? void 0 : _componentRef2.focus();
    expect(document.activeElement).toBe(button);
  });
  it('should pass the type attribute', () => {
    render(_Button2 || (_Button2 = _jsx(Button, {
      type: "submit",
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'submit');
  });
  it('should pass the `elementRef` prop', () => {
    const elementRef = vi.fn();
    render(_jsx(Button, {
      elementRef: elementRef,
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(elementRef).toHaveBeenCalledWith(button);
  });
  it('should pass the `as` prop', () => {
    const _render = render(_Button3 || (_Button3 = _jsx(Button, {
        as: "li",
        children: "Hello"
      }))),
      container = _render.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello');
    expect(button.tagName).toBe('LI');
  });
  it('should set the disabled attribute when `interaction` is set to disabled', () => {
    render(_Button4 || (_Button4 = _jsx(Button, {
      interaction: "disabled",
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `disabled` is set', () => {
    render(_Button5 || (_Button5 = _jsx(Button, {
      disabled: true,
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `interaction` is set to readonly', () => {
    render(_Button6 || (_Button6 = _jsx(Button, {
      interaction: "readonly",
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `readOnly` is set', () => {
    render(_Button7 || (_Button7 = _jsx(Button, {
      readOnly: true,
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should pass the `href` prop', () => {
    render(_Button8 || (_Button8 = _jsx(Button, {
      href: "#",
      children: "Hello"
    })));
    const linkButton = screen.getByRole('link', {
      name: 'Hello'
    });
    expect(linkButton).toBeInTheDocument();
    expect(linkButton).toHaveAttribute('href', '#');
  });
  it('should pass the `renderIcon` prop', () => {
    render(_Button9 || (_Button9 = _jsx(Button, {
      renderIcon: icon,
      children: "Hello"
    })));
    const svgIcon = document.querySelector(iconSelector);
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
  });
  it('should pass the `onClick` prop', async () => {
    const onClick = vi.fn();
    render(_jsx(Button, {
      onClick: onClick,
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    await userEvent.click(button);
    await waitFor(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
  it('should render the children as button text', () => {
    render(_Button10 || (_Button10 = _jsx(Button, {
      children: "Hello World"
    })));
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello World');
  });
  it('should not error with a null child', () => {
    render(_Button11 || (_Button11 = _jsxs(Button, {
      children: ["Hello World", null]
    })));
    const button = screen.getByRole('button', {
      name: 'Hello World'
    });
    expect(button).toBeInTheDocument();
  });
  it('should render a link styled as a button if href is provided', () => {
    render(_Button12 || (_Button12 = _jsx(Button, {
      href: "example.html",
      children: "Hello World"
    })));
    const button = screen.getAllByRole('link', {
      name: 'Hello World'
    });
    expect(button).toHaveLength(1);
    expect(button[0]).toHaveAttribute('href', 'example.html');
  });
  it('should render as a link when `to` prop is provided', () => {
    const _render2 = render(_Button13 || (_Button13 = _jsx(Button, {
        to: "/example",
        children: "Test"
      }))),
      container = _render2.container;
    const linkButton = container.querySelector('a');
    expect(linkButton).toBeInTheDocument();
    expect(linkButton).toHaveAttribute('to', '/example');
  });
  it('should render designated tag if `as` prop is specified', () => {
    const _render3 = render(_Button14 || (_Button14 = _jsx(Button, {
        as: "span",
        children: "Hello World"
      }))),
      container = _render3.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello World');
    expect(button.tagName).toBe('SPAN');
  });
  it('should set role="button"', () => {
    const onClick = vi.fn();
    const _render4 = render(_jsx(Button, {
        as: "span",
        onClick: onClick,
        children: "Hello World"
      })),
      container = _render4.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('role', 'button');
  });
  it('should set tabIndex="0"', () => {
    const onClick = vi.fn();
    render(_jsx(Button, {
      as: "span",
      onClick: onClick,
      children: "Hello World"
    }));
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('tabIndex', '0');
  });
  it('should pass down the type prop to the button element', () => {
    const onClick = vi.fn();
    render(_jsx(Button, {
      type: "submit",
      onClick: onClick,
      children: "Hello World"
    }));
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'submit');
  });
  it('focuses with the focus helper', () => {
    const onFocus = vi.fn();
    render(_jsx(Button, {
      onFocus: onFocus,
      children: "Hello World"
    }));
    const button = screen.getByRole('button');
    button.focus();
    expect(onFocus).toHaveBeenCalled();
    expect(document.activeElement).toBe(button);
  });
  describe('onClick', () => {
    it('should call onClick when clicked', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        onClick: onClick,
        children: "Hello World"
      }));
      const button = screen.getByRole('button', {
        name: 'Hello World'
      });
      await userEvent.click(button);
      await waitFor(() => {
        expect(onClick).toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is disabled', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        disabled: true,
        onClick: onClick,
        children: "Hello World"
      }));
      const button = screen.getByRole('button', {
        name: 'Hello World'
      });
      await userEvent.click(button);
      await waitFor(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is readOnly', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        readOnly: true,
        onClick: onClick,
        children: "Hello World"
      }));
      const button = screen.getByRole('button', {
        name: 'Hello World'
      });
      await userEvent.click(button);
      await waitFor(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is disabled and an href prop is provided', async () => {
      const onClick = vi.fn();
      render(_Button15 || (_Button15 = _jsx(Button, {
        href: "#",
        children: "Hello World"
      })));
      const button = screen.getByRole('link', {
        name: 'Hello World'
      });
      await userEvent.click(button);
      await waitFor(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is readOnly and an href prop is provided', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        readOnly: true,
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = screen.getByRole('link', {
        name: 'Hello World'
      });
      await userEvent.click(button);
      await waitFor(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should call onClick when space key is pressed if href is provided', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = screen.getByRole('link', {
        name: 'Hello World'
      });
      await userEvent.type(button, '{space}');
      await waitFor(() => {
        expect(onClick).toHaveBeenCalled();
      });
    });
    it('should call onClick when enter key is pressed when not a button or link', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        as: "span",
        onClick: onClick,
        children: "Hello World"
      }));
      const button = screen.getByRole('button', {
        name: 'Hello World'
      });
      await userEvent.type(button, '{enter}');
      await waitFor(() => {
        expect(onClick).toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is disabled and space key is pressed', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        disabled: true,
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = screen.getByRole('link', {
        name: 'Hello World'
      });
      await userEvent.type(button, '{spaec}');
      await waitFor(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is readOnly and space key is pressed', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        readOnly: true,
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = screen.getByRole('link', {
        name: 'Hello World'
      });
      await userEvent.type(button, '{space}');
      await waitFor(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
  });
  describe('for a11y', () => {
    it('should meet standards when onClick is given', async () => {
      const onClick = vi.fn();
      render(_jsx(Button, {
        onClick: onClick,
        children: "Hello World"
      }));
      const button = screen.getByRole('button', {
        name: 'Hello World'
      });
      await userEvent.click(button);
      await waitFor(async () => {
        const axeCheck = await runAxeCheck(button);
        expect(axeCheck).toBe(true);
      });
    });
    describe('when disabled', () => {
      it('sets the disabled attribute so that the button is not in tab order', () => {
        render(_Button16 || (_Button16 = _jsx(Button, {
          disabled: true,
          children: "Hello World"
        })));
        const button = screen.getByRole('button', {
          name: 'Hello World'
        });
        expect(button).toHaveAttribute('disabled');
      });
    });
    describe('when readOnly', () => {
      it('sets the disabled attribute so that the button is not in tab order', () => {
        render(_Button17 || (_Button17 = _jsx(Button, {
          readOnly: true,
          children: "Hello World"
        })));
        const button = screen.getByRole('button', {
          name: 'Hello World'
        });
        expect(button).toHaveAttribute('disabled');
      });
    });
  });
});