var _circle, _CondensedButton, _CondensedButton2, _CondensedButton3, _CondensedButton4, _CondensedButton5, _CondensedButton6, _CondensedButton7;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, screen, waitFor } from '@testing-library/react';
import { vi } from 'vitest';
import userEvent from '@testing-library/user-event';
import '@testing-library/jest-dom';
import { CondensedButton } from '../index';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
describe('<CondensedButton/>', () => {
  var _CondensedButton8;
  const icon = _jsx("svg", {
    "data-title": "myIcon",
    height: "1em",
    width: "1em",
    style: {
      fill: 'currentcolor'
    },
    children: _circle || (_circle = _jsx("circle", {
      cx: "0.5em",
      cy: "0.5em",
      r: "0.5em"
    }))
  });
  const iconSelector = 'svg[data-title="myIcon"]';
  it('should render children', () => {
    const children = 'Hello world';
    render(_jsx(CondensedButton, {
      children: children
    }));
    const button = document.querySelector('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent(children);
  });
  it('should provide a focused getter', () => {
    var _componentRef;
    let componentRef;
    render(_jsx(CondensedButton, {
      ref: component => {
        componentRef = component;
      },
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    button.focus();
    expect((_componentRef = componentRef) === null || _componentRef === void 0 ? void 0 : _componentRef.focused).toBe(true);
  });
  it('should provide a focus function', () => {
    var _componentRef2;
    let componentRef;
    render(_jsx(CondensedButton, {
      ref: component => {
        componentRef = component;
      },
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    (_componentRef2 = componentRef) === null || _componentRef2 === void 0 ? void 0 : _componentRef2.focus();
    expect(document.activeElement).toBe(button);
  });
  it('should pass the type attribute', () => {
    render(_CondensedButton || (_CondensedButton = _jsx(CondensedButton, {
      type: "submit",
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'submit');
  });
  it('should pass the `elementRef` prop', async () => {
    const elementRef = vi.fn();
    render(_jsx(CondensedButton, {
      elementRef: elementRef,
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(elementRef).toHaveBeenCalledWith(button);
  });
  it('should pass the `as` prop', () => {
    const _render = render(_CondensedButton2 || (_CondensedButton2 = _jsx(CondensedButton, {
        as: "li",
        children: "Hello"
      }))),
      container = _render.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello');
    expect(button.tagName).toBe('LI');
  });
  it('should set the disabled attribute when `interaction` is set to disabled', () => {
    render(_CondensedButton3 || (_CondensedButton3 = _jsx(CondensedButton, {
      interaction: "disabled",
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `disabled` is set', () => {
    render(_CondensedButton4 || (_CondensedButton4 = _jsx(CondensedButton, {
      disabled: true,
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `interaction` is set to readonly', () => {
    render(_CondensedButton5 || (_CondensedButton5 = _jsx(CondensedButton, {
      interaction: "readonly",
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `readOnly` is set', () => {
    render(_CondensedButton6 || (_CondensedButton6 = _jsx(CondensedButton, {
      readOnly: true,
      children: "Hello"
    })));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should pass the `href` prop', () => {
    render(_CondensedButton7 || (_CondensedButton7 = _jsx(CondensedButton, {
      href: "#",
      children: "Hello"
    })));
    const linkButton = screen.getByRole('link', {
      name: 'Hello'
    });
    expect(linkButton).toBeInTheDocument();
    expect(linkButton).toHaveAttribute('href', '#');
  });
  it('should pass the `renderIcon` prop', async () => {
    render(_CondensedButton8 || (_CondensedButton8 = _jsx(CondensedButton, {
      renderIcon: icon,
      children: "Hello"
    })));
    const svgIcon = document.querySelector(iconSelector);
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
  });
  it('should pass the `onClick` prop', async () => {
    const onClick = vi.fn();
    render(_jsx(CondensedButton, {
      onClick: onClick,
      children: "Hello"
    }));
    const button = screen.getByRole('button', {
      name: 'Hello'
    });
    await userEvent.click(button);
    await waitFor(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
});