var _circle;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, screen, waitFor } from '@testing-library/react';
import { vi } from 'vitest';
import userEvent from '@testing-library/user-event';
import '@testing-library/jest-dom';
import { IconButton } from '../index';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
describe('<IconButton/>', () => {
  var _IconButton, _IconButton2, _IconButton3, _IconButton4, _IconButton5, _IconButton6, _IconButton7, _IconButton8, _IconButton9;
  const icon = _jsx("svg", {
    "data-title": "myIcon",
    height: "1em",
    width: "1em",
    style: {
      fill: 'currentcolor'
    },
    children: _circle || (_circle = _jsx("circle", {
      cx: "0.5em",
      cy: "0.5em",
      r: "0.5em"
    }))
  });
  const iconSelector = 'svg[data-title="myIcon"]';
  it('should render an icon when provided as the `children` prop', () => {
    render(_IconButton || (_IconButton = _jsx(IconButton, {
      screenReaderLabel: "some action",
      children: icon
    })));
    const svgIcon = document.querySelector(iconSelector);
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
    expect(button).toHaveTextContent('some action');
  });
  it('should render an icon when provided as the `renderIcon` prop', () => {
    render(_IconButton2 || (_IconButton2 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon
    })));
    const svgIcon = document.querySelector(iconSelector);
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
  });
  it('should provide a focused getter', () => {
    var _componentRef;
    let componentRef;
    render(_jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      ref: component => {
        componentRef = component;
      }
    }));
    const button = screen.getByRole('button');
    button.focus();
    expect((_componentRef = componentRef) === null || _componentRef === void 0 ? void 0 : _componentRef.focused).toBe(true);
  });
  it('should provide a focus function', () => {
    var _componentRef2;
    let componentRef;
    render(_jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      ref: component => {
        componentRef = component;
      }
    }));
    const button = screen.getByRole('button');
    (_componentRef2 = componentRef) === null || _componentRef2 === void 0 ? void 0 : _componentRef2.focus();
    expect(document.activeElement).toBe(button);
  });
  it('should pass the `href` prop', () => {
    render(_IconButton3 || (_IconButton3 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      href: "#"
    })));
    const linkButton = screen.getByRole('link');
    expect(linkButton).toBeInTheDocument();
    expect(linkButton).toHaveAttribute('href', '#');
  });
  it('should pass the `type` prop', () => {
    render(_IconButton4 || (_IconButton4 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      type: "reset"
    })));
    const button = screen.getByRole('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'reset');
  });
  it('should pass the `elementRef` prop', () => {
    const elementRef = vi.fn();
    render(_jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      elementRef: elementRef
    }));
    const button = screen.getByRole('button');
    expect(elementRef).toHaveBeenCalledWith(button);
  });
  it('should pass the `as` prop', () => {
    const _render = render(_IconButton5 || (_IconButton5 = _jsx(IconButton, {
        screenReaderLabel: "some action",
        renderIcon: icon,
        as: "li"
      }))),
      container = _render.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('some action');
    expect(button.tagName).toBe('LI');
  });
  it('should set the disabled attribute when `interaction` is set to disabled', () => {
    render(_IconButton6 || (_IconButton6 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      interaction: "disabled"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `disabled` is set', () => {
    render(_IconButton7 || (_IconButton7 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      disabled: true
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `interaction` is set to readonly', () => {
    render(_IconButton8 || (_IconButton8 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      interaction: "readonly"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `readOnly` is set', () => {
    render(_IconButton9 || (_IconButton9 = _jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      readOnly: true
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should pass the `onClick` prop', async () => {
    const onClick = vi.fn();
    render(_jsx(IconButton, {
      screenReaderLabel: "some action",
      renderIcon: icon,
      onClick: onClick
    }));
    const button = screen.getByRole('button');
    await userEvent.click(button);
    await waitFor(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
});