var _svg;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, screen, waitFor } from '@testing-library/react';
import { vi } from 'vitest';
import userEvent from '@testing-library/user-event';
import '@testing-library/jest-dom';
import { ToggleButton } from '../index';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
describe('<ToggleButton />', () => {
  var _ToggleButton, _ToggleButton2, _ToggleButton3, _ToggleButton4, _ToggleButton5, _ToggleButton6, _ToggleButton7, _ToggleButton8, _ToggleButton9;
  const icon = _svg || (_svg = _jsx("svg", {
    "data-title": "myIcon",
    height: "1em",
    width: "1em",
    children: _jsx("circle", {
      cx: "0.5em",
      cy: "0.5em",
      r: "0.5em"
    })
  }));
  const iconSelector = 'svg[data-title="myIcon"]';
  it('should render', () => {
    render(_ToggleButton || (_ToggleButton = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    const svgIcon = document.querySelector(iconSelector);
    const tooltip = screen.getByRole('tooltip');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('This is a screen reader label');
    expect(svgIcon).toBeInTheDocument();
    expect(tooltip).toBeInTheDocument();
    expect(tooltip).toHaveTextContent('This is tooltip content');
  });
  it('should set `aria-pressed` to `true` if `status` is `pressed`', () => {
    render(_ToggleButton2 || (_ToggleButton2 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('aria-pressed', 'true');
  });
  it('should set `aria-pressed` to `false` if `status` is `unpressed`', () => {
    render(_ToggleButton3 || (_ToggleButton3 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "unpressed"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('aria-pressed', 'false');
  });
  it('should render an icon', () => {
    render(_ToggleButton4 || (_ToggleButton4 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    const svgIcon = document.querySelector(iconSelector);
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
  });
  it('should pass the `as` prop', () => {
    const _render = render(_ToggleButton5 || (_ToggleButton5 = _jsx(ToggleButton, {
        screenReaderLabel: "This is a screen reader label",
        renderIcon: icon,
        renderTooltipContent: "This is tooltip content",
        as: "li",
        status: "pressed"
      }))),
      container = _render.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button.tagName).toBe('LI');
  });
  it('should set the disabled attribute when `interaction` prop is set to disabled', () => {
    render(_ToggleButton6 || (_ToggleButton6 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      interaction: "disabled",
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `disabled` prop is set', () => {
    render(_ToggleButton7 || (_ToggleButton7 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      disabled: true,
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `interaction` prop is set to readonly', () => {
    render(_ToggleButton8 || (_ToggleButton8 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      interaction: "readonly",
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `readOnly` prop is set', () => {
    render(_ToggleButton9 || (_ToggleButton9 = _jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      readOnly: true,
      status: "pressed"
    })));
    const button = screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should pass the `onClick` prop', async () => {
    const onClick = vi.fn();
    render(_jsx(ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      onClick: onClick,
      status: "pressed"
    }));
    const button = screen.getByRole('button');
    await userEvent.click(button);
    await waitFor(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
});