"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _index = require("../index");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _BaseButton, _BaseButton2, _BaseButton3, _BaseButton4, _BaseButton5, _svg, _BaseButton6, _BaseButton7, _BaseButton8, _BaseButton9, _BaseButton10, _BaseButton11;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<BaseButton/>', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render a button and the children as button text', () => {
    (0, _react.render)(_BaseButton || (_BaseButton = (0, _jsxRuntime.jsx)(_index.BaseButton, {
      children: "Hello World"
    })));
    const button = document.querySelector('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello World');
  });
  it('should not error with a null child', () => {
    (0, _react.render)(_BaseButton2 || (_BaseButton2 = (0, _jsxRuntime.jsxs)(_index.BaseButton, {
      children: ["Hello World", null]
    })));
    const button = document.querySelector('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello World');
  });
  it('should render a link styled as a button if href is provided', () => {
    (0, _react.render)(_BaseButton3 || (_BaseButton3 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
      href: "example.html",
      children: "Hello World"
    })));
    const linkButton = _react.screen.getByRole('link', {
      name: 'Hello World'
    });
    expect(linkButton).toBeInTheDocument();
    expect(linkButton).toHaveAttribute('href', 'example.html');
  });
  it('should render as a link when `to` prop is provided', () => {
    const _render = (0, _react.render)(_BaseButton4 || (_BaseButton4 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
        to: "/example",
        children: "Test"
      }))),
      container = _render.container;
    const linkButton = container.querySelector('a');
    expect(linkButton.getAttribute('to')).toBe('/example');
  });
  it('should render designated tag if `as` prop is specified', () => {
    const _render2 = (0, _react.render)(_BaseButton5 || (_BaseButton5 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
        as: "span",
        children: "Hello World"
      }))),
      container = _render2.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello World');
    expect(button.tagName).toBe('SPAN');
  });
  it('should set role="button"', () => {
    const onClick = _vitest.vi.fn();
    const _render3 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        as: "span",
        onClick: onClick,
        children: "Hello World"
      })),
      container = _render3.container;
    const button = container.querySelector('span[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('role', 'button');
  });
  it('should set tabIndex="0"', () => {
    const onClick = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
      as: "span",
      onClick: onClick,
      children: "Hello World"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello World'
    });
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('tabIndex', '0');
  });
  it('should not set tabIndex="0" when the element has it by default', () => {
    const onClick = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [(0, _jsxRuntime.jsx)(_index.BaseButton, {
        as: "button",
        onClick: onClick,
        children: "Hello Button"
      }), (0, _jsxRuntime.jsx)(_index.BaseButton, {
        onClick: onClick,
        href: "example.html",
        children: "Hello link"
      })]
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello Button'
    });
    expect(button).toBeInTheDocument();
    expect(button).not.toHaveAttribute('tabIndex');
    const link = _react.screen.getByRole('link', {
      name: 'Hello link'
    });
    expect(link).toBeInTheDocument();
    expect(link).not.toHaveAttribute('tabIndex');
  });
  it('should pass down the type prop to the button element', async () => {
    const onClick = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
      type: "submit",
      onClick: onClick,
      children: "Hello World"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello World'
    });
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'submit');
  });
  it('should pass down an icon via the icon property', () => {
    const SomeIcon = () => _svg || (_svg = (0, _jsxRuntime.jsx)("svg", {
      children: (0, _jsxRuntime.jsx)("circle", {
        cx: "25",
        cy: "75",
        r: "20"
      })
    }));
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
      renderIcon: SomeIcon,
      children: "Hello World"
    }));
    const icon = document.querySelector('svg');
    expect(icon).toBeInTheDocument();
  });
  it('focuses with the focus helper', async () => {
    (0, _react.render)(_BaseButton6 || (_BaseButton6 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
      children: "Hello World"
    })));
    const button = _react.screen.getByRole('button', {
      name: 'Hello World'
    });
    button.focus();
    expect(document.activeElement).toBe(button);
  });
  it('should provide an elementRef prop', async () => {
    const elementRef = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
      elementRef: elementRef,
      children: "Hello World"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello World'
    });
    expect(elementRef).toBeCalledWith(button);
  });
  describe('onClick', () => {
    it('should call onClick when clicked', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).toHaveBeenCalledTimes(1);
      });
    });
    it('should not call onClick when interaction is "disabled"', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        interaction: "disabled",
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when disabled is set"', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        disabled: true,
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when interaction is "readonly"', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        interaction: "readonly",
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when readOnly is set', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        readOnly: true,
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when button is disabled and an href prop is provided', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)(_BaseButton7 || (_BaseButton7 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
        href: "#",
        children: "Hello World"
      })));
      const button = _react.screen.getByRole('link', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when interaction is "readonly" and an href prop is provided', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        interaction: "readonly",
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('link', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should call onClick when space key is pressed if href is provided', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('link', {
        name: 'Hello World'
      });
      await _userEvent.default.type(button, '{space}');
      await (0, _react.waitFor)(() => {
        expect(onClick).toHaveBeenCalled();
      });
    });
    it('should call onClick when enter key is pressed when not a button or link', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        as: "span",
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.type(button, '{enter}');
      await (0, _react.waitFor)(() => {
        expect(onClick).toHaveBeenCalled();
      });
    });
    it('should not call onClick when interaction is "disabled" and space key is pressed', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        interaction: "disabled",
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('link', {
        name: 'Hello World'
      });
      await _userEvent.default.type(button, '{space}');
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
    it('should not call onClick when interaction is "readonly" and space key is pressed', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        interaction: "readonly",
        onClick: onClick,
        href: "#",
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('link', {
        name: 'Hello World'
      });
      await _userEvent.default.type(button, '{space}');
      await (0, _react.waitFor)(() => {
        expect(onClick).not.toHaveBeenCalled();
      });
    });
  });
  describe('when passing down props to View', () => {
    it("passes cursor='pointer' to View by default", async () => {
      (0, _react.render)(_BaseButton8 || (_BaseButton8 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
        children: "Hello World"
      })));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      const style = window.getComputedStyle(button);
      expect(style.cursor).toBe('pointer');
    });
    it("passes cursor='not-allowed' to View when disabled", async () => {
      (0, _react.render)(_BaseButton9 || (_BaseButton9 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
        interaction: "disabled",
        children: "Hello World"
      })));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      const style = window.getComputedStyle(button);
      expect(style.cursor).toBe('not-allowed');
    });
  });
  describe('for a11y', () => {
    it('should meet standards when onClick is given', async () => {
      const onClick = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.BaseButton, {
        onClick: onClick,
        children: "Hello World"
      }));
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.click(button);
      await (0, _react.waitFor)(async () => {
        const axeCheck = await (0, _runAxeCheck.runAxeCheck)(button);
        expect(axeCheck).toBe(true);
      });
    });
    describe('when disabled', () => {
      it('sets the disabled attribute so that the button is not in tab order', () => {
        (0, _react.render)(_BaseButton10 || (_BaseButton10 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
          interaction: "disabled",
          children: "Hello World"
        })));
        const button = _react.screen.getByRole('button', {
          name: 'Hello World'
        });
        expect(button).toHaveAttribute('disabled');
      });
    });
    describe('when readonly', () => {
      it('sets the disabled attribute so that the button is not in tab order', async () => {
        (0, _react.render)(_BaseButton11 || (_BaseButton11 = (0, _jsxRuntime.jsx)(_index.BaseButton, {
          interaction: "readonly",
          children: "Hello World"
        })));
        const button = _react.screen.getByRole('button', {
          name: 'Hello World'
        });
        expect(button).toHaveAttribute('disabled');
      });
    });
  });
});