"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _circle, _CondensedButton, _CondensedButton2, _CondensedButton3, _CondensedButton4, _CondensedButton5, _CondensedButton6, _CondensedButton7;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<CondensedButton/>', () => {
  var _CondensedButton8;
  const icon = (0, _jsxRuntime.jsx)("svg", {
    "data-title": "myIcon",
    height: "1em",
    width: "1em",
    style: {
      fill: 'currentcolor'
    },
    children: _circle || (_circle = (0, _jsxRuntime.jsx)("circle", {
      cx: "0.5em",
      cy: "0.5em",
      r: "0.5em"
    }))
  });
  const iconSelector = 'svg[data-title="myIcon"]';
  it('should render children', () => {
    const children = 'Hello world';
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.CondensedButton, {
      children: children
    }));
    const button = document.querySelector('button');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent(children);
  });
  it('should provide a focused getter', () => {
    var _componentRef;
    let componentRef;
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.CondensedButton, {
      ref: component => {
        componentRef = component;
      },
      children: "Hello"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    button.focus();
    expect((_componentRef = componentRef) === null || _componentRef === void 0 ? void 0 : _componentRef.focused).toBe(true);
  });
  it('should provide a focus function', () => {
    var _componentRef2;
    let componentRef;
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.CondensedButton, {
      ref: component => {
        componentRef = component;
      },
      children: "Hello"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    (_componentRef2 = componentRef) === null || _componentRef2 === void 0 ? void 0 : _componentRef2.focus();
    expect(document.activeElement).toBe(button);
  });
  it('should pass the type attribute', () => {
    (0, _react.render)(_CondensedButton || (_CondensedButton = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      type: "submit",
      children: "Hello"
    })));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toBeInTheDocument();
    expect(button).toHaveAttribute('type', 'submit');
  });
  it('should pass the `elementRef` prop', async () => {
    const elementRef = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.CondensedButton, {
      elementRef: elementRef,
      children: "Hello"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(elementRef).toHaveBeenCalledWith(button);
  });
  it('should pass the `as` prop', () => {
    const _render = (0, _react.render)(_CondensedButton2 || (_CondensedButton2 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
        as: "li",
        children: "Hello"
      }))),
      container = _render.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('Hello');
    expect(button.tagName).toBe('LI');
  });
  it('should set the disabled attribute when `interaction` is set to disabled', () => {
    (0, _react.render)(_CondensedButton3 || (_CondensedButton3 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      interaction: "disabled",
      children: "Hello"
    })));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `disabled` is set', () => {
    (0, _react.render)(_CondensedButton4 || (_CondensedButton4 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      disabled: true,
      children: "Hello"
    })));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `interaction` is set to readonly', () => {
    (0, _react.render)(_CondensedButton5 || (_CondensedButton5 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      interaction: "readonly",
      children: "Hello"
    })));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `readOnly` is set', () => {
    (0, _react.render)(_CondensedButton6 || (_CondensedButton6 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      readOnly: true,
      children: "Hello"
    })));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toHaveAttribute('disabled');
  });
  it('should pass the `href` prop', () => {
    (0, _react.render)(_CondensedButton7 || (_CondensedButton7 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      href: "#",
      children: "Hello"
    })));
    const linkButton = _react.screen.getByRole('link', {
      name: 'Hello'
    });
    expect(linkButton).toBeInTheDocument();
    expect(linkButton).toHaveAttribute('href', '#');
  });
  it('should pass the `renderIcon` prop', async () => {
    (0, _react.render)(_CondensedButton8 || (_CondensedButton8 = (0, _jsxRuntime.jsx)(_index.CondensedButton, {
      renderIcon: icon,
      children: "Hello"
    })));
    const svgIcon = document.querySelector(iconSelector);
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
  });
  it('should pass the `onClick` prop', async () => {
    const onClick = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.CondensedButton, {
      onClick: onClick,
      children: "Hello"
    }));
    const button = _react.screen.getByRole('button', {
      name: 'Hello'
    });
    await _userEvent.default.click(button);
    await (0, _react.waitFor)(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
});