"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _svg;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<ToggleButton />', () => {
  var _ToggleButton, _ToggleButton2, _ToggleButton3, _ToggleButton4, _ToggleButton5, _ToggleButton6, _ToggleButton7, _ToggleButton8, _ToggleButton9;
  const icon = _svg || (_svg = (0, _jsxRuntime.jsx)("svg", {
    "data-title": "myIcon",
    height: "1em",
    width: "1em",
    children: (0, _jsxRuntime.jsx)("circle", {
      cx: "0.5em",
      cy: "0.5em",
      r: "0.5em"
    })
  }));
  const iconSelector = 'svg[data-title="myIcon"]';
  it('should render', () => {
    (0, _react.render)(_ToggleButton || (_ToggleButton = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    const svgIcon = document.querySelector(iconSelector);
    const tooltip = _react.screen.getByRole('tooltip');
    expect(button).toBeInTheDocument();
    expect(button).toHaveTextContent('This is a screen reader label');
    expect(svgIcon).toBeInTheDocument();
    expect(tooltip).toBeInTheDocument();
    expect(tooltip).toHaveTextContent('This is tooltip content');
  });
  it('should set `aria-pressed` to `true` if `status` is `pressed`', () => {
    (0, _react.render)(_ToggleButton2 || (_ToggleButton2 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    expect(button).toHaveAttribute('aria-pressed', 'true');
  });
  it('should set `aria-pressed` to `false` if `status` is `unpressed`', () => {
    (0, _react.render)(_ToggleButton3 || (_ToggleButton3 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "unpressed"
    })));
    const button = _react.screen.getByRole('button');
    expect(button).toHaveAttribute('aria-pressed', 'false');
  });
  it('should render an icon', () => {
    (0, _react.render)(_ToggleButton4 || (_ToggleButton4 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    const svgIcon = document.querySelector(iconSelector);
    expect(button).toBeInTheDocument();
    expect(svgIcon).toBeInTheDocument();
  });
  it('should pass the `as` prop', () => {
    const _render = (0, _react.render)(_ToggleButton5 || (_ToggleButton5 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
        screenReaderLabel: "This is a screen reader label",
        renderIcon: icon,
        renderTooltipContent: "This is tooltip content",
        as: "li",
        status: "pressed"
      }))),
      container = _render.container;
    const button = container.querySelector('[type="button"]');
    expect(button).toBeInTheDocument();
    expect(button.tagName).toBe('LI');
  });
  it('should set the disabled attribute when `interaction` prop is set to disabled', () => {
    (0, _react.render)(_ToggleButton6 || (_ToggleButton6 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      interaction: "disabled",
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `disabled` prop is set', () => {
    (0, _react.render)(_ToggleButton7 || (_ToggleButton7 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      disabled: true,
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `interaction` prop is set to readonly', () => {
    (0, _react.render)(_ToggleButton8 || (_ToggleButton8 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      interaction: "readonly",
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should set the disabled attribute when `readOnly` prop is set', () => {
    (0, _react.render)(_ToggleButton9 || (_ToggleButton9 = (0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      readOnly: true,
      status: "pressed"
    })));
    const button = _react.screen.getByRole('button');
    expect(button).toHaveAttribute('disabled');
  });
  it('should pass the `onClick` prop', async () => {
    const onClick = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.ToggleButton, {
      screenReaderLabel: "This is a screen reader label",
      renderIcon: icon,
      renderTooltipContent: "This is tooltip content",
      onClick: onClick,
      status: "pressed"
    }));
    const button = _react.screen.getByRole('button');
    await _userEvent.default.click(button);
    await (0, _react.waitFor)(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
});