import React from 'react';
import type { Spacing, WithStyleProps } from '@instructure/emotion';
import type { ToProp, AsElementType, PropValidators, BaseButtonTheme, OtherHTMLAttributes } from '@instructure/shared-types';
import type { Cursor } from '@instructure/ui-prop-types';
import type { ViewProps } from '@instructure/ui-view';
type ButtonOwnProps = {
    /**
     * Specifies the `Button` children.
     */
    children?: React.ReactNode;
    /**
     * Specifies the type of the `Button`'s underlying html element.
     */
    type?: 'button' | 'submit' | 'reset';
    /**
     * The size of the `Button`
     */
    size?: 'small' | 'medium' | 'large';
    /**
     * Provides a reference to the `Button`'s underlying html element.
     */
    elementRef?: (element: Element | null) => void;
    /**
     * The element to render as the component root, `Button` by default.
     */
    as?: AsElementType;
    /**
     * Specifies if interaction with the `Button` is enabled, disabled, or readonly.
     */
    interaction?: 'enabled' | 'disabled' | 'readonly';
    /**
     * Specifies the color for the `Button`.
     */
    color?: 'primary' | 'primary-inverse' | 'secondary' | 'success' | 'danger' | 'ai-primary' | 'ai-secondary';
    /**
     * Override the `Button`'s default focus outline color.
     */
    focusColor?: 'info' | 'inverse';
    /**
     * The `Button` display property. When set to `inline-block`, the `Button` displays inline with other elements.
     * When set to block, the `Button` expands to fill the width of the container.
     */
    display?: 'inline-block' | 'block';
    /**
     * Sets the alignment of the `Button` children and/or icon.
     */
    textAlign?: 'start' | 'center';
    /**
     * Specifies if the `Button` should render with a solid background. When false, the background is transparent.
     */
    withBackground?: boolean;
    /**
     * Valid values are `0`, `none`, `auto`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `margin="small auto large"`.
     */
    margin?: Spacing;
    /**
     * Specify a mouse cursor to use when hovering over the button.
     * The `pointer` cursor is used by default.
     */
    cursor?: Cursor;
    /**
     * Specifies an href attribute for the `Button`'s underlying html element.
     */
    href?: string;
    /**
     * An icon, or function that returns an icon.
     */
    renderIcon?: React.ReactNode | (() => React.ReactNode);
    /**
     * Callback fired when the `Button` is clicked.
     */
    onClick?: (event: React.KeyboardEvent<ViewProps> | React.MouseEvent<ViewProps>) => void;
};
type PropKeys = keyof ButtonOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type ButtonProps = ButtonOwnProps & WithStyleProps<BaseButtonTheme, null> & OtherHTMLAttributes<ButtonOwnProps> & ToProp;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { ButtonProps };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map